@@ -91,6 +91,31 @@ void MprisControlPlugin::sendPlaybackInfo(std::variant<NetworkPacket, QString> c
     np.set(QStringLiteral("canPlay"), playbackControls.IsPlayEnabled());
     np.set(QStringLiteral("canGoNext"), playbackControls.IsNextEnabled());
     np.set(QStringLiteral("canGoPrevious"), playbackControls.IsPreviousEnabled());
+    np.set(QStringLiteral("canSeek"), playbackControls.IsPlaybackPositionEnabled());
+
+    if (playbackInfo.IsShuffleActive()) {
+        const bool shuffleStatus = playbackInfo.IsShuffleActive().Value();
+        np.set(QStringLiteral("shuffle"), shuffleStatus);
+    }
+
+    if (playbackInfo.AutoRepeatMode()) {
+        QString loopStatus;
+        switch(playbackInfo.AutoRepeatMode().Value()) {
+            case Windows::Media::MediaPlaybackAutoRepeatMode::List: {
+                loopStatus = QStringLiteral("Playlist");
+                break;
+                }
+            case Windows::Media::MediaPlaybackAutoRepeatMode::Track: {
+                loopStatus = QStringLiteral("Track");
+                break;
+                }
+            default: {
+                loopStatus = QStringLiteral("None");
+                break;
+                }
+        }
+        np.set(QStringLiteral("loopStatus"), loopStatus);
+    }
 
     sendTimelineProperties(np, player);
 
@@ -106,7 +131,9 @@ void MprisControlPlugin::sendTimelineProperties(std::variant<NetworkPacket, QStr
     auto timelineProperties = player.GetTimelineProperties();
 
     if(!lengthOnly){
-        np.set(QStringLiteral("canSeek"), timelineProperties.MinSeekTime() != timelineProperties.MaxSeekTime());
+        const auto playbackInfo = player.GetPlaybackInfo();
+        const auto playbackControls = playbackInfo.Controls();
+        np.set(QStringLiteral("canSeek"), playbackControls.IsPlaybackPositionEnabled());
         np.set(QStringLiteral("pos"), std::chrono::duration_cast<std::chrono::milliseconds>(timelineProperties.Position() - timelineProperties.StartTime()).count());
     }
     np.set(QStringLiteral("length"), std::chrono::duration_cast<std::chrono::milliseconds>(timelineProperties.EndTime() - timelineProperties.StartTime()).count());
@@ -128,11 +155,19 @@ void MprisControlPlugin::updatePlayerList() {
 
     for(uint32_t i = 0; i < sessions.Size(); i++) {
         const auto player = sessions.GetAt(i);
+        auto playerName = player.SourceAppUserModelId();
 
-        QString name = QString::fromWCharArray(player.SourceAppUserModelId().c_str());
-        QString uniqueName  = name;
+#if WIN_SDK_VERSION >= 19041
+        // try to resolve the AUMID to a user-friendly name
+        try {
+            playerName = AppInfo::GetFromAppUserModelId(playerName).DisplayInfo().DisplayName();
+        } catch (winrt::hresult_error e) {
+            qCDebug(KDECONNECT_PLUGIN_MPRIS) << QString::fromWCharArray(playerName.c_str()) << "doesn\'t have a valid AppUserModelID! Sending as-is..";
+        }
+#endif
+        QString uniqueName = QString::fromWCharArray(playerName.c_str());
         for (int i = 2; playerList.contains(uniqueName); ++i) {
-            uniqueName = name + QStringLiteral(" [") + QString::number(i) + QStringLiteral("]");
+            uniqueName += QStringLiteral(" [") + QString::number(i) + QStringLiteral("]");
         }
 
         playerList.insert(uniqueName, player);
@@ -284,6 +319,25 @@ bool MprisControlPlugin::receivePacket(const NetworkPacket &np)
         player.TryChangePlaybackPositionAsync((player.GetTimelineProperties().StartTime() + position).count()).get();
     }
 
+    if (np.has(QStringLiteral("setShuffle")))
+    {
+        player.TryChangeShuffleActiveAsync(np.get<bool>(QStringLiteral("setShuffle")));
+    }
+
+    if (np.has(QStringLiteral("setLoopStatus")))
+    {
+        QString loopStatus = np.get<QString>(QStringLiteral("setLoopStatus"));
+        enum class winrt::Windows::Media::MediaPlaybackAutoRepeatMode loopStatusEnumVal;
+        if (loopStatus == QStringLiteral("Track")) {
+            loopStatusEnumVal = Windows::Media::MediaPlaybackAutoRepeatMode::Track;
+        } else if (loopStatus == QStringLiteral("Playlist")) {
+            loopStatusEnumVal = Windows::Media::MediaPlaybackAutoRepeatMode::List;
+        } else {
+            loopStatusEnumVal = Windows::Media::MediaPlaybackAutoRepeatMode::None;
+        }
+        player.TryChangeAutoRepeatModeAsync(loopStatusEnumVal);
+    }
+
     //Send something read from the mpris interface
     NetworkPacket answer(PACKET_TYPE_MPRIS);
     answer.set(QStringLiteral("player"), name);
@@ -293,7 +347,8 @@ bool MprisControlPlugin::receivePacket(const NetworkPacket &np)
         somethingToSend = true;
     }
     if (np.get<bool>(QStringLiteral("requestVolume"))) {
-        answer.set(QStringLiteral("volume"), 100);
+        // we don't support setting per-app volume levels yet
+        answer.set(QStringLiteral("volume"), -1);
         somethingToSend = true;
     }
 
