@@ -26,7 +26,10 @@
 
 int main(int argc, char *argv[])
 {
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
+
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
     KAboutData aboutData(QStringLiteral("kdeconnect.sms"),
